@@ -10,18 +10,17 @@ to a public caning.
 import functools
 import email.utils
 import re
+import builtins
 from binascii import b2a_base64
 from cgi import parse_header
 from email.header import decode_header
+from http.server import BaseHTTPRequestHandler
+from urllib.parse import unquote_plus
 
-import six
-from six.moves import range, builtins
-from six.moves.BaseHTTPServer import BaseHTTPRequestHandler
+import jaraco.collections
 
 import cherrypy
 from cherrypy._cpcompat import ntob, ntou
-from cherrypy._cpcompat import text_or_bytes
-from cherrypy._cpcompat import unquote_qs
 
 response_codes = BaseHTTPRequestHandler.responses.copy()
 
@@ -144,7 +143,7 @@ class HeaderElement(object):
         return self.value < other.value
 
     def __str__(self):
-        p = [';%s=%s' % (k, v) for k, v in six.iteritems(self.params)]
+        p = [';%s=%s' % (k, v) for k, v in self.params.items()]
         return str('%s%s' % (self.value, ''.join(p)))
 
     def __bytes__(self):
@@ -210,14 +209,11 @@ class AcceptElement(HeaderElement):
 
             Ref: https://github.com/cherrypy/cherrypy/issues/1370
             """
-            six.raise_from(
-                cherrypy.HTTPError(
-                    400,
-                    'Malformed HTTP header: `{}`'.
-                    format(str(self)),
-                ),
-                val_err,
-            )
+            raise cherrypy.HTTPError(
+                400,
+                'Malformed HTTP header: `{}`'.
+                format(str(self)),
+            ) from val_err
 
     def __cmp__(self, other):
         diff = builtins.cmp(self.qvalue, other.qvalue)
@@ -284,11 +280,11 @@ def valid_status(status):
     If status has no reason-phrase is supplied, a default reason-
     phrase will be provided.
 
-    >>> from six.moves import http_client
-    >>> from six.moves.BaseHTTPServer import BaseHTTPRequestHandler
-    >>> valid_status(http_client.ACCEPTED) == (
-    ...     int(http_client.ACCEPTED),
-    ... ) + BaseHTTPRequestHandler.responses[http_client.ACCEPTED]
+    >>> import http.client
+    >>> from http.server import BaseHTTPRequestHandler
+    >>> valid_status(http.client.ACCEPTED) == (
+    ...     int(http.client.ACCEPTED),
+    ... ) + BaseHTTPRequestHandler.responses[http.client.ACCEPTED]
     True
     """
 
@@ -296,7 +292,7 @@ def valid_status(status):
         status = 200
 
     code, reason = status, None
-    if isinstance(status, six.string_types):
+    if isinstance(status, str):
         code, _, reason = status.partition(' ')
         reason = reason.strip() or None
 
@@ -360,8 +356,8 @@ def _parse_qs(qs, keep_blank_values=0, strict_parsing=0, encoding='utf-8'):
             else:
                 continue
         if len(nv[1]) or keep_blank_values:
-            name = unquote_qs(nv[0], encoding)
-            value = unquote_qs(nv[1], encoding)
+            name = unquote_plus(nv[0], encoding, errors='strict')
+            value = unquote_plus(nv[1], encoding, errors='strict')
             if name in d:
                 if not isinstance(d[name], list):
                     d[name] = [d[name]]
@@ -391,77 +387,19 @@ def parse_query_string(query_string, keep_blank_values=True, encoding='utf-8'):
     return pm
 
 
-####
-# Inlined from jaraco.collections 1.5.2
-# Ref #1673
-class KeyTransformingDict(dict):
-    """
-    A dict subclass that transforms the keys before they're used.
-    Subclasses may override the default transform_key to customize behavior.
-    """
-    @staticmethod
-    def transform_key(key):
-        return key
-
-    def __init__(self, *args, **kargs):
-        super(KeyTransformingDict, self).__init__()
-        # build a dictionary using the default constructs
-        d = dict(*args, **kargs)
-        # build this dictionary using transformed keys.
-        for item in d.items():
-            self.__setitem__(*item)
-
-    def __setitem__(self, key, val):
-        key = self.transform_key(key)
-        super(KeyTransformingDict, self).__setitem__(key, val)
-
-    def __getitem__(self, key):
-        key = self.transform_key(key)
-        return super(KeyTransformingDict, self).__getitem__(key)
-
-    def __contains__(self, key):
-        key = self.transform_key(key)
-        return super(KeyTransformingDict, self).__contains__(key)
-
-    def __delitem__(self, key):
-        key = self.transform_key(key)
-        return super(KeyTransformingDict, self).__delitem__(key)
-
-    def get(self, key, *args, **kwargs):
-        key = self.transform_key(key)
-        return super(KeyTransformingDict, self).get(key, *args, **kwargs)
-
-    def setdefault(self, key, *args, **kwargs):
-        key = self.transform_key(key)
-        return super(KeyTransformingDict, self).setdefault(
-            key, *args, **kwargs)
-
-    def pop(self, key, *args, **kwargs):
-        key = self.transform_key(key)
-        return super(KeyTransformingDict, self).pop(key, *args, **kwargs)
-
-    def matching_key_for(self, key):
-        """
-        Given a key, return the actual key stored in self that matches.
-        Raise KeyError if the key isn't found.
-        """
-        try:
-            return next(e_key for e_key in self.keys() if e_key == key)
-        except StopIteration:
-            raise KeyError(key)
-####
-
-
-class CaseInsensitiveDict(KeyTransformingDict):
+class CaseInsensitiveDict(jaraco.collections.KeyTransformingDict):
 
     """A case-insensitive dict subclass.
 
-    Each key is changed on entry to str(key).title().
+    Each key is changed on entry to title case.
     """
 
     @staticmethod
     def transform_key(key):
-        return str(key).title()
+        if key is None:
+            # TODO(#1830): why?
+            return 'None'
+        return key.title()
 
 
 #   TEXT = <any OCTET except CTLs, but including LWS>
@@ -500,9 +438,7 @@ class HeaderMap(CaseInsensitiveDict):
 
     def elements(self, key):
         """Return a sorted list of HeaderElements for the given header."""
-        key = str(key).title()
-        value = self.get(key)
-        return header_elements(key, value)
+        return header_elements(self.transform_key(key), self.get(key))
 
     def values(self, key):
         """Return a sorted list of HeaderElement.value for the given header."""
@@ -519,23 +455,20 @@ class HeaderMap(CaseInsensitiveDict):
         transmitting on the wire for HTTP.
         """
         for k, v in header_items:
-            if isinstance(k, six.text_type):
-                k = cls.encode(k)
-
-            if not isinstance(v, text_or_bytes):
+            if not isinstance(v, str) and not isinstance(v, bytes):
                 v = str(v)
 
-            if isinstance(v, six.text_type):
-                v = cls.encode(v)
+            yield tuple(map(cls.encode_header_item, (k, v)))
 
-            # See header_translate_* constants above.
-            # Replace only if you really know what you're doing.
-            k = k.translate(header_translate_table,
-                            header_translate_deletechars)
-            v = v.translate(header_translate_table,
-                            header_translate_deletechars)
+    @classmethod
+    def encode_header_item(cls, item):
+        if isinstance(item, str):
+            item = cls.encode(item)
 
-            yield (k, v)
+        # See header_translate_* constants above.
+        # Replace only if you really know what you're doing.
+        return item.translate(
+            header_translate_table, header_translate_deletechars)
 
     @classmethod
     def encode(cls, v):
