@@ -352,18 +352,17 @@ class PipelineTests(helper.CPWebCase):
         conn._output(ntob('Host: %s' % self.HOST, 'ascii'))
         conn._send_output()
         response = conn.response_class(conn.sock, method='GET')
+        msg = (
+            "Writing to timed out socket didn't fail as it should have: %s")
         try:
             response.begin()
         except Exception:
             if not isinstance(sys.exc_info()[1],
                               (socket.error, BadStatusLine)):
-                self.fail("Writing to timed out socket didn't fail"
-                          ' as it should have: %s' % sys.exc_info()[1])
+                self.fail(msg % sys.exc_info()[1])
         else:
             if response.status != 408:
-                self.fail("Writing to timed out socket didn't fail"
-                          ' as it should have: %s' %
-                          response.read())
+                self.fail(msg % response.read())
 
         conn.close()
 
@@ -379,24 +378,21 @@ class PipelineTests(helper.CPWebCase):
         self.body = response.read()
         self.assertBody(pov)
 
-        # BROKEN
-        # # Make another request on the same socket,
-        # # but timeout on the headers
-        # conn.send(b'GET /hello HTTP/1.1')
-        # # Wait for our socket timeout
-        # time.sleep(timeout * 2)
-        # response = conn.response_class(conn.sock, method='GET')
-        # try:
-        #     response.begin()
-        # except Exception:
-        #     if not isinstance(sys.exc_info()[1],
-        #                       (socket.error, BadStatusLine)):
-        #         self.fail("Writing to timed out socket didn't fail"
-        #                   ' as it should have: %s' % sys.exc_info()[1])
-        # else:
-        #     self.fail("Writing to timed out socket didn't fail"
-        #               ' as it should have: %s' %
-        #               response.read())
+        # Make another request on the same socket,
+        # but timeout on the headers
+        conn.send(b'GET /hello HTTP/1.1')
+        # Wait for our socket timeout
+        time.sleep(timeout * 2)
+        response = conn.response_class(conn.sock, method='GET')
+        try:
+            response.begin()
+        except Exception:
+            if not isinstance(sys.exc_info()[1],
+                              (socket.error, BadStatusLine)):
+                self.fail(msg % sys.exc_info()[1])
+        else:
+            if response.status != 408:
+                self.fail(msg % response.read())
 
         conn.close()
 
